Enumeration

ClapperDiscovererDiscoveryMode

deprecated: 0.10 

Declaration

enum Clapper.DiscovererDiscoveryMode

Description

No description available.

Deprecated since: 0.10

Use Media Scanner from clapper-enhancers repo instead.

Members

CLAPPER_DISCOVERER_DISCOVERY_ALWAYS

Run discovery for every single media item added to ClapperQueue. This mode is useful when application presents a list of items to select from to the user before playback. It will scan every single item in queue, so user can have an updated list of items when selecting what to play.

  • Value: 0
  • Available since: 0.0
CLAPPER_DISCOVERER_DISCOVERY_NONCURRENT

Only run discovery on an item if it is not a currently selected item in ClapperQueue. This mode is optimal when application always plays (or at least goes into paused) after selecting item from queue. It will skip discovery of such items since they will be discovered by ClapperPlayer anyway.

  • Value: 1
  • Available since: 0.0